# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLEDDriverModelnaam(KeuzelijstField):
    """De modelnaam van de LED-driver."""
    naam = 'KlLEDDriverModelnaam'
    label = 'LED-driver modelnaam'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLEDDriverModelnaam'
    definition = 'De modelnaam van de LED-driver.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLEDDriverModelnaam'
    options = {
        'ebs-080s070bt2': KeuzelijstWaarde(invulwaarde='ebs-080s070bt2',
                                           label='ebs-080s070bt2',
                                           status='ingebruik',
                                           definitie='ebs-080s070bt2',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/ebs-080s070bt2'),
        'elg-100-c350b-3y': KeuzelijstWaarde(invulwaarde='elg-100-c350b-3y',
                                             label='ELG 100 C350B 3Y',
                                             status='ingebruik',
                                             definitie='ELG 100 C350B 3Y',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/elg-100-c350b-3y'),
        'eum-320s105bg': KeuzelijstWaarde(invulwaarde='eum-320s105bg',
                                          label='EUM-320S105BG',
                                          status='ingebruik',
                                          definitie='EUM-320S105BG',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/eum-320s105bg'),
        'hlg-320h-c700b': KeuzelijstWaarde(invulwaarde='hlg-320h-c700b',
                                           label='HLG 320H C700B',
                                           status='ingebruik',
                                           definitie='HLG 320H C700B',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/hlg-320h-c700b'),
        'ot-dx-110-220-240-1a0-dima-lt2-e': KeuzelijstWaarde(invulwaarde='ot-dx-110-220-240-1a0-dima-lt2-e',
                                                             label='OT DX 110 220-240 1A0 DIMA LT2 E',
                                                             status='ingebruik',
                                                             definitie='OT DX 110 220-240 1A0 DIMA LT2 E',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/ot-dx-110-220-240-1a0-dima-lt2-e'),
        'ot-dx-165-220-240-1a0-dima-lt2-e': KeuzelijstWaarde(invulwaarde='ot-dx-165-220-240-1a0-dima-lt2-e',
                                                             label='OT DX 165 220-240 1A0 DIMA LT2 E',
                                                             status='ingebruik',
                                                             definitie='OT DX 165 220-240 1A0 DIMA LT2 E',
                                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/ot-dx-165-220-240-1a0-dima-lt2-e'),
        'ot-dx-40-220-240-1a0-dima-lt2-e': KeuzelijstWaarde(invulwaarde='ot-dx-40-220-240-1a0-dima-lt2-e',
                                                            label='OT DX 40 220-240 1A0 DIMA LT2 E',
                                                            status='ingebruik',
                                                            definitie='OT DX 40 220-240 1A0 DIMA LT2 E',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/ot-dx-40-220-240-1a0-dima-lt2-e'),
        'ot-dx-75-220-240-1a0-dima-lt2-e': KeuzelijstWaarde(invulwaarde='ot-dx-75-220-240-1a0-dima-lt2-e',
                                                            label='OT DX 75 220-240 1A0 DIMA LT2 E',
                                                            status='ingebruik',
                                                            definitie='OT DX 75 220-240 1A0 DIMA LT2 E',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/ot-dx-75-220-240-1a0-dima-lt2-e'),
        'slc-g3-r3-sp0b-p0': KeuzelijstWaarde(invulwaarde='slc-g3-r3-sp0b-p0',
                                              label='SLC-G3-R3-SP0B-P0',
                                              status='ingebruik',
                                              definitie='SLC-G3-R3-SP0B-P0',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/slc-g3-r3-sp0b-p0'),
        'slc-g3-r3-sp0b-pm': KeuzelijstWaarde(invulwaarde='slc-g3-r3-sp0b-pm',
                                              label='SLC-G3-R3-SP0B-PM',
                                              status='ingebruik',
                                              definitie='SLC-G3-R3-SP0B-PM',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/slc-g3-r3-sp0b-pm'),
        'xi-fp-110w-0-2-0-7a-snldae-230v-c133-sxt': KeuzelijstWaarde(invulwaarde='xi-fp-110w-0-2-0-7a-snldae-230v-c133-sxt',
                                                                     label='Xi FP 110W 0.2-0.7A SNLDAE 230V C133 sXt',
                                                                     status='ingebruik',
                                                                     definitie='Xi FP 110W 0.2-0.7A SNLDAE 230V C133 sXt',
                                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/xi-fp-110w-0-2-0-7a-snldae-230v-c133-sxt'),
        'xi-fp-110w-0-3-1-0a-snldae-230v-c133-sxt': KeuzelijstWaarde(invulwaarde='xi-fp-110w-0-3-1-0a-snldae-230v-c133-sxt',
                                                                     label='Xi FP 110W 0.3-1.0A SNLDAE 230V C133 sXt',
                                                                     status='ingebruik',
                                                                     definitie='Xi FP 110W 0.3-1.0A SNLDAE 230V C133 sXt',
                                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/xi-fp-110w-0-3-1-0a-snldae-230v-c133-sxt'),
        'xi-fp-75w-0-2-0-7a-snldae-230v-c133-sxt': KeuzelijstWaarde(invulwaarde='xi-fp-75w-0-2-0-7a-snldae-230v-c133-sxt',
                                                                    label='Xi FP 75W 0.2-0.7A SNLDAE 230V C133 sXt',
                                                                    status='ingebruik',
                                                                    definitie='Xi FP 75W 0.2-0.7A SNLDAE 230V C133 sXt',
                                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/xi-fp-75w-0-2-0-7a-snldae-230v-c133-sxt'),
        'xi-sr-110w-0-2-0-7a-snemp-230v-c150-sxt': KeuzelijstWaarde(invulwaarde='xi-sr-110w-0-2-0-7a-snemp-230v-c150-sxt',
                                                                    label='Xi SR 110W 0.2-0.7A SNEMP 230V C150 sXt',
                                                                    status='ingebruik',
                                                                    definitie='Xi SR 110W 0.2-0.7A SNEMP 230V C150 sXt',
                                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/xi-sr-110w-0-2-0-7a-snemp-230v-c150-sxt'),
        'xi-sr-150w-0-2-0-7a-snemp-230v-s240-sxt': KeuzelijstWaarde(invulwaarde='xi-sr-150w-0-2-0-7a-snemp-230v-s240-sxt',
                                                                    label='Xi SR 150W 0.2-0.7A SNEMP 230V S240 sXt',
                                                                    status='ingebruik',
                                                                    definitie='Xi SR 150W 0.2-0.7A SNEMP 230V S240 sXt',
                                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/xi-sr-150w-0-2-0-7a-snemp-230v-s240-sxt'),
        'xi-sr-40w-0-2-0-7a-snemp-230v-c133-sxt': KeuzelijstWaarde(invulwaarde='xi-sr-40w-0-2-0-7a-snemp-230v-c133-sxt',
                                                                   label='Xi SR 40W 0.2-0.7A SNEMP 230V C133 sXt',
                                                                   status='ingebruik',
                                                                   definitie='Xi SR 40W 0.2-0.7A SNEMP 230V C133 sXt',
                                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/xi-sr-40w-0-2-0-7a-snemp-230v-c133-sxt'),
        'xi-sr-40w-0-2-1-0a-snemp-230v-c123-sxt': KeuzelijstWaarde(invulwaarde='xi-sr-40w-0-2-1-0a-snemp-230v-c123-sxt',
                                                                   label='Xi SR 40W 0.2-1.0A SNEMP 230V C123 sXt',
                                                                   status='ingebruik',
                                                                   definitie='Xi SR 40W 0.2-1.0A SNEMP 230V C123 sXt',
                                                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/xi-sr-40w-0-2-1-0a-snemp-230v-c123-sxt'),
        'xitanium-fp': KeuzelijstWaarde(invulwaarde='xitanium-fp',
                                        label='Xitanium FP',
                                        status='ingebruik',
                                        definitie='Xitanium FP',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEDDriverModelnaam/xitanium-fp')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

