# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlPutRooster(KeuzelijstField):
    """Types rooster van de put."""
    naam = 'KlPutRooster'
    label = 'Putrooster'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlPutRooster'
    definition = 'Types rooster van de put.'
    status = 'ingebruik'
    deprecated_version = '2.1.0'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlPutRooster'
    options = {
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-180-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-180-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 480 x 330 x 180 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 480 x 330 x 180 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-180-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-200-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-200-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 480 x 330 x 200 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 480 x 330 x 200 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-200-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-230-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-230-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 480 x 330 x 230 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 480 x 330 x 230 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-230-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-535-x-330-x-168-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-535-x-330-x-168-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 535 x 330 x 168 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 535 x 330 x 168 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-535-x-330-x-168-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-280-x-230-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-280-x-230-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 540 x 280 x 230 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 540 x 280 x 230 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-280-x-230-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-340-x-180-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-340-x-180-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 540 x 340 x 180 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 540 x 340 x 180 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-340-x-180-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-340-x-240-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-340-x-240-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 540 x 340 x 240 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 540 x 340 x 240 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-340-x-240-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-605-x-290-x-205-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-605-x-290-x-205-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 605 x 290 x 205 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 605 x 290 x 205 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-605-x-290-x-205-mm'),
        'volledig-gietijzeren-straatkolk': KeuzelijstWaarde(invulwaarde='volledig-gietijzeren-straatkolk',
                                                            label='volledig gietijzeren straatkolk',
                                                            status='ingebruik',
                                                            definitie='volledig gietijzeren straatkolk',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/volledig-gietijzeren-straatkolk'),
        'volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-500-x-500-x-640-mm': KeuzelijstWaarde(invulwaarde='volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-500-x-500-x-640-mm',
                                                                                                       label='volledig gietijzeren straatkolk zichtvlak x hoogte min. 500 x 500 x 640 mm',
                                                                                                       status='ingebruik',
                                                                                                       definitie='volledig gietijzeren straatkolk zichtvlak x hoogte: min. 500 x 500 x 640 mm',
                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-500-x-500-x-640-mm'),
        'volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-500-x-500-x-650-mm': KeuzelijstWaarde(invulwaarde='volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-500-x-500-x-650-mm',
                                                                                                       label='volledig gietijzeren straatkolk zichtvlak x hoogte min. 500 x 500 x 650 mm',
                                                                                                       status='ingebruik',
                                                                                                       definitie='volledig gietijzeren straatkolk zichtvlak x hoogte: min. 500 x 500 x 650 mm',
                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-500-x-500-x-650-mm'),
        'volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-665-x-230-x-570-mm': KeuzelijstWaarde(invulwaarde='volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-665-x-230-x-570-mm',
                                                                                                       label='volledig gietijzeren straatkolk zichtvlak x hoogte min. 665 x 230 x 570 mm',
                                                                                                       status='ingebruik',
                                                                                                       definitie='volledig gietijzeren straatkolk zichtvlak x hoogte: min. 665 x 230 x 570 mm',
                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-665-x-230-x-570-mm'),
        'volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-785-x-300-x-400-mm': KeuzelijstWaarde(invulwaarde='volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-785-x-300-x-400-mm',
                                                                                                       label='volledig gietijzeren straatkolk zichtvlak x hoogte min. 785 x 300 x 400 mm',
                                                                                                       status='ingebruik',
                                                                                                       definitie='volledig gietijzeren straatkolk zichtvlak x hoogte: min. 785 x 300 x 400 mm',
                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-785-x-300-x-400-mm'),
        'volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-785-x-300-x-655-mm': KeuzelijstWaarde(invulwaarde='volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-785-x-300-x-655-mm',
                                                                                                       label='volledig gietijzeren straatkolk zichtvlak x hoogte min. 785 x 300 x 655 mm',
                                                                                                       status='ingebruik',
                                                                                                       definitie='volledig gietijzeren straatkolk zichtvlak x hoogte: min. 785 x 300 x 655 mm',
                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-785-x-300-x-655-mm')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

