# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBVMengseltype(KeuzelijstField):
    """het mengseltype van de butimineuze verharding."""
    naam = 'KlBVMengseltype'
    label = 'BV mengseltype'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBVMengseltype'
    definition = 'het mengseltype van de butimineuze verharding.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBVMengseltype'
    options = {
        'AB-1B': KeuzelijstWaarde(invulwaarde='AB-1B',
                                  label='AB-1B',
                                  status='ingebruik',
                                  definitie='AB-1B',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-1B'),
        'AB-2C': KeuzelijstWaarde(invulwaarde='AB-2C',
                                  label='AB-2C',
                                  status='ingebruik',
                                  definitie='AB-2C',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-2C'),
        'AB-3A': KeuzelijstWaarde(invulwaarde='AB-3A',
                                  label='AB-3A',
                                  status='ingebruik',
                                  definitie='AB-3A',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-3A'),
        'AB-3B': KeuzelijstWaarde(invulwaarde='AB-3B',
                                  label='AB-3B',
                                  status='ingebruik',
                                  definitie='AB-3B',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-3B'),
        'AB-3C': KeuzelijstWaarde(invulwaarde='AB-3C',
                                  label='AB-3C',
                                  status='ingebruik',
                                  definitie='AB-3C',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-3C'),
        'AB-3D': KeuzelijstWaarde(invulwaarde='AB-3D',
                                  label='AB-3D',
                                  status='ingebruik',
                                  definitie='AB-3D',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-3D'),
        'AB-4C': KeuzelijstWaarde(invulwaarde='AB-4C',
                                  label='AB-4C',
                                  status='ingebruik',
                                  definitie='AB-4C',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-4C'),
        'AB-4D': KeuzelijstWaarde(invulwaarde='AB-4D',
                                  label='AB-4D',
                                  status='ingebruik',
                                  definitie='AB-4D',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-4D'),
        'AB-5D': KeuzelijstWaarde(invulwaarde='AB-5D',
                                  label='AB-5D',
                                  status='ingebruik',
                                  definitie='AB-5D',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AB-5D'),
        'ABT-B': KeuzelijstWaarde(invulwaarde='ABT-B',
                                  label='ABT-B',
                                  status='ingebruik',
                                  definitie='ABT-B',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/ABT-B'),
        'AGT-klasse-I': KeuzelijstWaarde(invulwaarde='AGT-klasse-I',
                                         label='AGT klasse I',
                                         status='ingebruik',
                                         definitie='AGT klasse I',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AGT-klasse-I'),
        'AGT-klasse-II': KeuzelijstWaarde(invulwaarde='AGT-klasse-II',
                                          label='AGT klasse II',
                                          status='ingebruik',
                                          definitie='AGT klasse II',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AGT-klasse-II'),
        'APO-A': KeuzelijstWaarde(invulwaarde='APO-A',
                                  label='APO-A',
                                  status='ingebruik',
                                  definitie='APO-A',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/APO-A'),
        'APO-B': KeuzelijstWaarde(invulwaarde='APO-B',
                                  label='APO-B',
                                  status='ingebruik',
                                  definitie='APO-B',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/APO-B'),
        'APO-C': KeuzelijstWaarde(invulwaarde='APO-C',
                                  label='APO-C',
                                  status='ingebruik',
                                  definitie='APO-C',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/APO-C'),
        'APO-D': KeuzelijstWaarde(invulwaarde='APO-D',
                                  label='APO-D',
                                  status='ingebruik',
                                  definitie='APO-D',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/APO-D'),
        'APT-C': KeuzelijstWaarde(invulwaarde='APT-C',
                                  label='APT-C',
                                  status='ingebruik',
                                  definitie='APT-C',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/APT-C'),
        'APT-D': KeuzelijstWaarde(invulwaarde='APT-D',
                                  label='APT-D',
                                  status='ingebruik',
                                  definitie='APT-D',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/APT-D'),
        'AVS-B': KeuzelijstWaarde(invulwaarde='AVS-B',
                                  label='AVS-B',
                                  status='ingebruik',
                                  definitie='AVS-B',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/AVS-B'),
        'GA-C': KeuzelijstWaarde(invulwaarde='GA-C',
                                 label='GA-C',
                                 status='ingebruik',
                                 definitie='GA-C',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/GA-C'),
        'GA-D': KeuzelijstWaarde(invulwaarde='GA-D',
                                 label='GA-D',
                                 status='ingebruik',
                                 definitie='GA-D',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/GA-D'),
        'GA-E': KeuzelijstWaarde(invulwaarde='GA-E',
                                 label='GA-E',
                                 status='ingebruik',
                                 definitie='GA-E',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/GA-E'),
        'GAA-E': KeuzelijstWaarde(invulwaarde='GAA-E',
                                  label='GAA-E',
                                  status='ingebruik',
                                  definitie='GAA-E',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/GAA-E'),
        'GAB-D': KeuzelijstWaarde(invulwaarde='GAB-D',
                                  label='GAB-D',
                                  status='ingebruik',
                                  definitie='GAB-D',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/GAB-D'),
        'IA': KeuzelijstWaarde(invulwaarde='IA',
                               label='IA',
                               status='ingebruik',
                               definitie='IA',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IA'),
        'IB': KeuzelijstWaarde(invulwaarde='IB',
                               label='IB',
                               status='ingebruik',
                               definitie='IB',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IB'),
        'IC': KeuzelijstWaarde(invulwaarde='IC',
                               label='IC',
                               status='ingebruik',
                               definitie='IC',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IC'),
        'II': KeuzelijstWaarde(invulwaarde='II',
                               label='II',
                               status='ingebruik',
                               definitie='II',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/II'),
        'IIIA': KeuzelijstWaarde(invulwaarde='IIIA',
                                 label='IIIA',
                                 status='ingebruik',
                                 definitie='IIIA',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IIIA'),
        'IIIB': KeuzelijstWaarde(invulwaarde='IIIB',
                                 label='IIIB',
                                 status='ingebruik',
                                 definitie='IIIB',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IIIB'),
        'IIIC': KeuzelijstWaarde(invulwaarde='IIIC',
                                 label='IIIC',
                                 status='ingebruik',
                                 definitie='IIIC',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IIIC'),
        'IV': KeuzelijstWaarde(invulwaarde='IV',
                               label='IV',
                               status='ingebruik',
                               definitie='IV',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/IV'),
        'SMA-B1': KeuzelijstWaarde(invulwaarde='SMA-B1',
                                   label='SMA-B1',
                                   status='ingebruik',
                                   definitie='SMA-B1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/SMA-B1'),
        'SMA-B2': KeuzelijstWaarde(invulwaarde='SMA-B2',
                                   label='SMA-B2',
                                   status='ingebruik',
                                   definitie='SMA-B2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/SMA-B2'),
        'SMA-C1': KeuzelijstWaarde(invulwaarde='SMA-C1',
                                   label='SMA-C1',
                                   status='ingebruik',
                                   definitie='SMA-C1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/SMA-C1'),
        'SMA-C2': KeuzelijstWaarde(invulwaarde='SMA-C2',
                                   label='SMA-C2',
                                   status='ingebruik',
                                   definitie='SMA-C2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/SMA-C2'),
        'SMA-D1': KeuzelijstWaarde(invulwaarde='SMA-D1',
                                   label='SMA-D1',
                                   status='ingebruik',
                                   definitie='SMA-D1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/SMA-D1'),
        'SMA-D2': KeuzelijstWaarde(invulwaarde='SMA-D2',
                                   label='SMA-D2',
                                   status='ingebruik',
                                   definitie='SMA-D2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/SMA-D2'),
        'ZOA-B1': KeuzelijstWaarde(invulwaarde='ZOA-B1',
                                   label='ZOA-B1',
                                   status='ingebruik',
                                   definitie='ZOA-B1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/ZOA-B1'),
        'ZOA-B2': KeuzelijstWaarde(invulwaarde='ZOA-B2',
                                   label='ZOA-B2',
                                   status='ingebruik',
                                   definitie='ZOA-B2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/ZOA-B2'),
        'ZOA-C1': KeuzelijstWaarde(invulwaarde='ZOA-C1',
                                   label='ZOA-C1',
                                   status='ingebruik',
                                   definitie='ZOA-C1',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/ZOA-C1'),
        'ZOA-C2': KeuzelijstWaarde(invulwaarde='ZOA-C2',
                                   label='ZOA-C2',
                                   status='ingebruik',
                                   definitie='ZOA-C2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/ZOA-C2'),
        'gietasfalt': KeuzelijstWaarde(invulwaarde='gietasfalt',
                                       label='gietasfalt',
                                       status='ingebruik',
                                       definitie='gietasfalt',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/gietasfalt'),
        'onderlaag-APO-A-en-toplaag-AGT-klasse-I': KeuzelijstWaarde(invulwaarde='onderlaag-APO-A-en-toplaag-AGT-klasse-I',
                                                                    label='onderlaag APO-A en toplaag AGT klasse I',
                                                                    status='ingebruik',
                                                                    definitie='onderlaag APO-A en toplaag AGT klasse I',
                                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/onderlaag-APO-A-en-toplaag-AGT-klasse-I'),
        'onderlaag-APO-A-en-toplaag-AGT-klasse-II': KeuzelijstWaarde(invulwaarde='onderlaag-APO-A-en-toplaag-AGT-klasse-II',
                                                                     label='onderlaag APO-A en toplaag AGT klasse II',
                                                                     status='ingebruik',
                                                                     definitie='onderlaag APO-A en toplaag AGT klasse II',
                                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/onderlaag-APO-A-en-toplaag-AGT-klasse-II'),
        'onderlaag-APO-B-en-toplaag-AGT-klasse-I': KeuzelijstWaarde(invulwaarde='onderlaag-APO-B-en-toplaag-AGT-klasse-I',
                                                                    label='onderlaag APO-B en toplaag AGT klasse I',
                                                                    status='ingebruik',
                                                                    definitie='onderlaag APO-B en toplaag AGT klasse I',
                                                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/onderlaag-APO-B-en-toplaag-AGT-klasse-I'),
        'onderlaag-APO-B-en-toplaag-AGT-klasse-II': KeuzelijstWaarde(invulwaarde='onderlaag-APO-B-en-toplaag-AGT-klasse-II',
                                                                     label='onderlaag APO-B en toplaag AGT klasse II',
                                                                     status='ingebruik',
                                                                     definitie='onderlaag APO-B en toplaag AGT klasse II',
                                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/onderlaag-APO-B-en-toplaag-AGT-klasse-II'),
        'toplaag-van-SMA-C': KeuzelijstWaarde(invulwaarde='toplaag-van-SMA-C',
                                              label='toplaag van SMA-C',
                                              status='ingebruik',
                                              definitie='toplaag van SMA-C',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/toplaag-van-SMA-C'),
        'toplaag-van-SMA-D': KeuzelijstWaarde(invulwaarde='toplaag-van-SMA-D',
                                              label='toplaag van SMA-D',
                                              status='ingebruik',
                                              definitie='toplaag van SMA-D',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/toplaag-van-SMA-D'),
        'toplaag-van-ZOA-B': KeuzelijstWaarde(invulwaarde='toplaag-van-ZOA-B',
                                              label='toplaag van ZOA-B',
                                              status='ingebruik',
                                              definitie='toplaag van ZOA-B',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/toplaag-van-ZOA-B'),
        'toplaag-van-ZOA-C': KeuzelijstWaarde(invulwaarde='toplaag-van-ZOA-C',
                                              label='toplaag van ZOA-C',
                                              status='ingebruik',
                                              definitie='toplaag van ZOA-C',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBVMengseltype/toplaag-van-ZOA-C')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

